@@ -26,6 +26,8 @@ ROSTER_SIZE = {
     FAN_DUEL: {
         'NFL': 9,
         'NFL_MVP': 5,
+        'MLB_MVP': 5,
+        'NBA_MVP': 5,
         'NBA': 9,
         'MLB': 9,
         'WNBA': 7,
@@ -59,6 +61,8 @@ SALARY_CAP = {
     FAN_DUEL: {
         'NFL': 60_000,
         'NFL_MVP': 60_000,
+        'MLB_MVP': 35_000,
+        'NBA_MVP': 60_000,
         'NBA': 60_000,
         'MLB': 35_000,
         'WNBA': 40_000,
@@ -197,6 +201,17 @@ POSITIONS = {
             ['SS', 1, 2],
             ['OF', 3, 4],
         ],
+        'MLB_MVP': [
+            ['MVP', 1, 1],
+            ['STAR', 1, 1],
+            ['UTIL', 3, 3],
+        ],
+        'NBA_MVP': [
+            ['MVP', 1, 1],
+            ['STAR', 1, 1],
+            ['PRO', 1, 1],
+            ['UTIL', 2, 2],
+        ],
         'WNBA': [
             ['G', 3, 3],
             ['F', 4, 4],
@@ -337,12 +352,32 @@ FD_NFL_MVP_RULE_SET = RuleSet(
     roster_size=ROSTER_SIZE[FAN_DUEL]['NFL_MVP'],
     salary_max=SALARY_CAP[FAN_DUEL]['NFL_MVP'],
     position_limits=POSITIONS[FAN_DUEL]['NFL_MVP'],
-    offensive_positions=['CAPT'],
+    offensive_positions=['CPT'],
     defensive_positions=['D'],
     general_position_limits=[],
     game_type='showdown',
 )
 
+FD_MLB_MVP_RULE_SET = RuleSet(
+    site=FAN_DUEL,
+    league='MLB_MVP',
+    roster_size=ROSTER_SIZE[FAN_DUEL]['MLB_MVP'],
+    salary_max=SALARY_CAP[FAN_DUEL]['MLB_MVP'],
+    position_limits=POSITIONS[FAN_DUEL]['MLB_MVP'],
+    general_position_limits=[],
+    game_type='showdown',
+)
+
+FD_NBA_MVP_RULE_SET = RuleSet(
+    site=FAN_DUEL,
+    league='NBA_MVP',
+    roster_size=ROSTER_SIZE[FAN_DUEL]['NBA_MVP'],
+    salary_max=SALARY_CAP[FAN_DUEL]['NBA_MVP'],
+    position_limits=POSITIONS[FAN_DUEL]['NBA_MVP'],
+    general_position_limits=[],
+    game_type='showdown',
+)
+
 FD_PGA_RULE_SET = RuleSet(
     site=FAN_DUEL,
     league='PGA',
